PAWpySeed: Member List

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

pawpyseed.core.projector.Projector Member List

This is the complete list of members for pawpyseed.core.projector.Projector, including all inherited members.

__init__(self, wf, basis, unsym_basis=False, unsym_wf=False, pseudo=False) | pawpyseed.core.projector.Projector |
basis | pawpyseed.core.projector.Projector |
check_c_projectors(self) | pawpyseed.core.wavefunction.Wavefunction |
coords | pawpyseed.core.projector.Projector |
cr | pawpyseed.core.projector.Projector |
defect_band_analysis(self, num_below_ef=20, num_above_ef=20, spinpol=False, return_energies=False, return_energy_list=False, vbmband=None) | pawpyseed.core.projector.Projector |
dim | pawpyseed.core.projector.Projector |
encut | pawpyseed.core.projector.Projector |
free_all(self) | pawpyseed.core.projector.Projector |
freed | pawpyseed.core.projector.Projector |
from_atomate_directory(path, setup_projectors=False) | pawpyseed.core.wavefunction.Wavefunction | static
from_directory(basis, path, unsym_basis=False, unsym_wf=False, pseudo=False) | pawpyseed.core.projector.Projector | static
pawpyseed::core::wavefunction::Wavefunction.from_directory(path, setup_projectors=False) | pawpyseed.core.wavefunction.Wavefunction | static
from_files(basis, struct="CONTCAR", pwf="WAVECAR", cr="POTCAR", vr="vasprun.xml", outcar="OUTCAR", unsym_basis=False, unsym_wf=False, pseudo=False) | pawpyseed.core.projector.Projector | static
pawpyseed::core::wavefunction::Wavefunction.from_files(struct="CONTCAR", pwf="WAVECAR", cr="POTCAR", vr="vasprun.xml", outcar="OUTCAR", setup_projectors=False) | pawpyseed.core.wavefunction.Wavefunction | static
get_c_projectors_from_pps(self, pps) | pawpyseed.core.wavefunction.Wavefunction |
get_kpt_mapping(self, allkpts, symprec=1e-5, gen_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_nosym_kpoints(self, init_kpts=None, symprec=1e-5, gen_trsym=True, fil_trsym=True) | pawpyseed.core.wavefunction.Wavefunction |
get_state_realspace(self, b, k, s, dim=None) | pawpyseed.core.wavefunction.Wavefunction |
get_symmops(self, symprec) | pawpyseed.core.wavefunction.Wavefunction |
kpts(self) | pawpyseed.core.wavefunction.Wavefunction |
kws(self) | pawpyseed.core.wavefunction.Wavefunction |
make_c_projectors(self) | pawpyseed.core.wavefunction.Wavefunction |
make_site_lists(self) | pawpyseed.core.projector.Projector |
nband | pawpyseed.core.projector.Projector |
nosym_kpts | pawpyseed.core.wavefunction.Wavefunction |
nspin | pawpyseed.core.projector.Projector |
num_proj_els | pawpyseed.core.projector.Projector |
nums | pawpyseed.core.projector.Projector |
nwk | pawpyseed.core.projector.Projector |
op_nums | pawpyseed.core.wavefunction.Wavefunction |
orig_kptnums | pawpyseed.core.wavefunction.Wavefunction |
projector_list | pawpyseed.core.projector.Projector |
projector_owner | pawpyseed.core.projector.Projector |
proportion_conduction(self, band_num, spinpol=False) | pawpyseed.core.projector.Projector |
pseudo | pawpyseed.core.projector.Projector |
pwf | pawpyseed.core.projector.Projector |
setup_bases(basis_dirs, desymmetrize=True, atomate_compatible=True) | pawpyseed.core.projector.Projector | static
setup_multiple_projections(basis_dir, wf_dirs, pseudo=False, ignore_errors=False, desymmetrize=False, atomate_compatible=True) | pawpyseed.core.projector.Projector | static
setup_overlap(self) | pawpyseed.core.projector.Projector |
single_band_projection(self, band_num) | pawpyseed.core.projector.Projector |
site_cat | pawpyseed.core.projector.Projector |
structure | pawpyseed.core.projector.Projector |
symmops | pawpyseed.core.wavefunction.Wavefunction |
wf | pawpyseed.core.projector.Projector |
write_density_realspace(self, filename="PYAECCAR", dim=None, return_wf=False) | pawpyseed.core.wavefunction.Wavefunction |
write_state_realspace(self, b, k, s, fileprefix="", dim=None, return_wf=False) | pawpyseed.core.wavefunction.Wavefunction |